/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_DIALOG_HXX_
# define WSCOUT_GUI_DIALOG_HXX_

# include <cassert>

# include "wscout_gui_dialog.hh"

namespace wscout
{

  namespace gui
  {

    inline
    Dialog::Dialog(QWidget* parent): QDialog (parent)
    {
      QGridLayout* const	l = new QGridLayout;

      l->setSizeConstraint(QLayout::SetFixedSize);
      setLayout(l);
    }

    inline
    QLabel*
    Dialog::makeLabel(const QString& s, Qt::Alignment align)
    {
      QLabel* const r = new QLabel (s, this);

      r->setAlignment(align);
      r->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
      return r;
    }

    inline
    QGridLayout&
    Dialog::layout()
    {
      QGridLayout* const l = dynamic_cast<QGridLayout*> (QDialog::layout());

      assert(l);
      return *l;
    }

    inline
    const QGridLayout&
    Dialog::layout() const
    {
      const QGridLayout* const l =
	dynamic_cast<const QGridLayout*> (QDialog::layout());

      assert(l);
      return *l;
    }

  } // End of namespace gui.

} // End of namespace wscout.

#endif // ! WSCOUT_GUI_DIALOG_HXX_
