/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007, 2008, 2009  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_IEEE802_11_BEACON_HEADER_HH_
# define WSCOUT_GUI_IEEE802_11_BEACON_HEADER_HH_

# include <QtGui/QLabel>

# include <wipal/wifi/timestamp.hh>

# include "wscout_gui_header_base.hh"

namespace wscout
{

  namespace gui
  {

    /**
     * IEEE 802.11 management frame bodies Widget.
     *
     * @see IEEE80211Header, AbstractHeader, HeaderBase
     */
    struct IEEE80211BeaconHeader:
      public HeaderBase<IEEE80211BeaconHeader, protocol::IEEE802_11_BEACON>
    {
      /// Default constructor.
      IEEE80211BeaconHeader(QWidget* parent = 0);

      /// Abstract method definition from AbstractHeader.
      virtual next_header	setup(const void*	header,
				      size_t		caplen,
				      const Trace&	trace,
				      const packet&	desc);
    private:

      struct frame_info_element
      {
	uint8_t		id;
	uint8_t		len;
	uint8_t		info[];
      };

      struct frame_body
      {
	wpl::wifi::timestamp	timestamp;
	uint16_t		beacon_interval;
	uint16_t		capability;
	uint8_t			info_elements[];
      };

      void			setupTimestamp(const frame_body& body);
      void			setupBeaconInterval(const frame_body&, bool s);
      void			setupCapability(const frame_body&, bool s);

      void			setupInfoElements(const frame_body&	body,
						  size_t		caplen,
						  bool			swap);

      const frame_info_element*	handleInfoElement(const frame_info_element* e,
						  bool			    s);

      QLabel	ssid;
      QLabel	capability;
      QLabel	timestamp;
      QLabel	beaconInterval;
    };

  } // End of namespace gui.

} // End of namespace wscout.

#endif // ! WSCOUT_GUI_IEEE802_11_BEACON_HEADER_HH_
