/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2008, 2009  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_IP_HEADER_HH_
# define WSCOUT_GUI_IP_HEADER_HH_

extern "C"
{
#include <netinet/ip.h>
}

# include <QtGui/QLabel>

# include "wscout_gui_header_base.hh"

namespace wscout
{

  namespace gui
  {

    /**
     * Base for IP header widgets (IPv4Header, IPv6Header).
     *
     * @see AbstractHeader, HeaderBase, IPv4Header, IPv6Header
     */
    template <class ExactIPHeader, int Protocol>
    struct IPHeader: public HeaderBase<ExactIPHeader, Protocol>
    {
      IPHeader(QWidget* parent = 0);

    protected:
      QLabel	srcDst_;
    };

    /**
     * IPv4 header widget.
     *
     * @see IPHeader, AbstractHeader, HeaderBase
     */
    struct IPv4Header: public IPHeader<IPv4Header, protocol::IPv4>
    {
      /// Default constructor.
      IPv4Header(QWidget* parent = 0);

      /// Abstract method definition from AbstractHeader.
      virtual next_header	setup(const void*	header,
				      size_t		caplen,
				      const Trace&	trace,
				      const packet&	desc);

    private:
      QLabel	ttl_;
      QLabel	fragInfo_;
    };

    /**
     * IPv6 header widget.
     *
     * @see IPHeader, AbstractHeader, HeaderBase
     */
    struct IPv6Header: public IPHeader<IPv6Header, protocol::IPv6>
    {
      /// Default constructor.
      IPv6Header(QWidget* parent = 0);

      /// Abstract method definition from AbstractHeader.
      virtual next_header	setup(const void*	header,
				      size_t		caplen,
				      const Trace&	trace,
				      const packet&	desc);

    private:
      QLabel	hopLimit_;
    };

  } // End of namespace gui.

} // End of namespace wscout.

# include "wscout_gui_ip_header.hxx"

#endif // ! WSCOUT_GUI_IP_HEADER_HH_
