/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_IP_HEADER_HXX_
# define WSCOUT_GUI_IP_HEADER_HXX_

# include "wscout_gui_ip_header.hh"

namespace wscout
{

  namespace gui
  {

    template <class ExactIPHeader, int Protocol>
    IPHeader<ExactIPHeader, Protocol>::IPHeader(QWidget* parent):
      HeaderBase<ExactIPHeader, Protocol> (parent)
    {
      this->setForegroundRole(QPalette::WindowText);
      this->setBackgroundRole(QPalette::Window);
      this->setAutoFillBackground(true);
      {
	QPalette	p;

	p.setColor(QPalette::WindowText, Qt::white);
	p.setColor(QPalette::Window, QColor ("seagreen"));
	this->setPalette(p);
      }

      {
	QFont	bold;
	bold.setBold(true);

	srcDst_.setFont(bold);
      }

      this->layout()->addWidget(&srcDst_);
    }

    inline
    IPv4Header::IPv4Header(QWidget* parent):
      IPHeader<IPv4Header, protocol::IPv4> (parent)
    {
      QBoxLayout* const l = layout();

      l->addWidget(&ttl_);
      l->addWidget(&fragInfo_);
    }

    inline
    IPv6Header::IPv6Header(QWidget* parent):
      IPHeader<IPv6Header, protocol::IPv6> (parent)
    {
      QBoxLayout* const l = layout();

      l->addWidget(&hopLimit_);
    }

  } // End of namespace gui.

} // End of namespace wscout.

#endif // ! WSCOUT_GUI_IP_HEADER_HXX_
