/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2008, 2009  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_LLC_HEADER_HH_
# define WSCOUT_GUI_LLC_HEADER_HH_

extern "C"
{
# include <inttypes.h>
}

# include <QtGui/QLabel>

# include "wscout_gui_header_base.hh"

namespace wscout
{

  namespace gui
  {

    /**
     * LLC header widget.
     *
     * @see AbstractHeader, HeaderBase
     */
    struct LLCHeader: public HeaderBase<LLCHeader, protocol::LLC>
    {
      /// Default constructor.
      LLCHeader(QWidget* parent = 0);

      /// Abstract method definition from AbstractHeader.
      virtual next_header	setup(const void*	header,
				      size_t		caplen,
				      const Trace&	trace,
				      const packet&	desc);

    private:

# define WSCOUT_PACKED_STRUCT	struct __attribute__((packed))

      WSCOUT_PACKED_STRUCT	dsap_addr
      {
	enum individual_group
	{
	  individual	= 0,
	  group		= 1
	};

	bool			ig:	1;
	unsigned		addr:	7;
      };


      WSCOUT_PACKED_STRUCT	ssap_addr
      {
	enum command_response
	  {
	    command	= 0,
	    response	= 1
	  };

	command_response	cr:	1;
	unsigned		addr:	7;
      };

      WSCOUT_PACKED_STRUCT	i_control
      {
	bool			pf() const;
	unsigned		snd_sn() const;
	unsigned		rcv_sn() const;

      private:
	unsigned		head:		1;
	unsigned		send_seqnum:	7;
	bool			poll_final:	1;
	unsigned		receive_seqnum:	7;
      };

      WSCOUT_PACKED_STRUCT	s_control
      {
	enum supervisory_function
	{
	  receive_ready		= 0,
	  reject		= 1,
	  receive_not_ready	= 2,
	  invalid		= 3
	};

	supervisory_function	sf() const;
	bool			pf() const;
	unsigned		rcv_sn() const;

      private:
	unsigned		head:		2;
	unsigned		superv_func:	2;
	unsigned		reserved:	4;
	bool			poll_final:	1;
	unsigned		receive_seqnum:	7;
      };

      WSCOUT_PACKED_STRUCT	u_control
      {
	enum command
	{
	  UI	= 0x00,
	  DM	= 0x03,
	  DISC	= 0x20,
	  UA	= 0x30,
	  AC0	= 0x31,
	  FRMR	= 0x41,
	  SABME	= 0x33,
	  XID	= 0x53,
	  TEST	= 0x70,
	  AC1	= 0x71
	};

	command		cmd() const;
	bool		pf() const;

      private:
	unsigned		head:		2;
	unsigned		m1:		2;
	bool			poll_final:	1;
	unsigned		m2:		3;
      };

      template <class Control>
      WSCOUT_PACKED_STRUCT	frame
      {
	dsap_addr		dsap;
	ssap_addr		ssap;
	Control			ctl;
	uint8_t			info[];
      };

      typedef frame<i_control>	i_frame;
      typedef frame<s_control>	s_frame;
      typedef frame<u_control>	u_frame;

# undef WSCOUT_PACKED_STRUCT

      enum frame_format
	{
	  information_transfer,
	  supervisory,
	  unnumbered,
	  unknown
	};

      static frame_format	format(const void* f, size_t caplen);
      static unsigned		as_byte(const dsap_addr& a);
      static unsigned		as_byte(const ssap_addr& a);

      template <class C>
      void
      setupDsapSsap(const frame<C>* header, size_t caplen);

      template <class C>
      next_header
      setup(const frame<C>*	header,
	    size_t		caplen,
	    std::ostream&	summary,
	    std::ostream&	control);

      QLabel	summary_;
      QLabel	dsapSsap_;
      QLabel	control_;
    };

  } // End of namespace gui.

} // End of namespace wscout.

# include "wscout_gui_llc_header.hxx"

#endif // ! WSCOUT_GUI_LLC_HEADER_HH_
