/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007, 2008, 2009  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_MAIN_WINDOW_HXX_
# define WSCOUT_GUI_MAIN_WINDOW_HXX_

# include <QtCore/QDir>
# include <QtCore/QFileInfo>
# include <QtGui/QApplication>

# include "wscout_gui_main_window.hh"

namespace wscout
{

  namespace gui
  {

    inline
    MainWindow::NewProgressDialog::NewProgressDialog(QProgressDialog**	d,
						     QMainWindow*	w):
      d_ (d),
      w_ (w)
    {
    }

    inline
    void
    MainWindow::NewProgressDialog::operator () (std::streampos min,
						std::streampos max)
    {
      QProgressDialog*&	d = *d_;

      d = new QProgressDialog (tr("Building Index...<br />"
				  "<b>Total size:</b> %1 MiB")
			       .arg(max / (1 << 20)),
			       tr("&Cancel"),
			       min >> 16,
			       max >> 16,
			       w_);
      d->setWindowTitle(tr("Building index..."));
      d->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
    }

    inline
    MainWindow::
    UpdateProgressDialog::UpdateProgressDialog(QProgressDialog** d): d_ (d)
    {
    }

    inline
    const std::string*
    MainWindow::UpdateProgressDialog::operator () (std::streampos cur)
    {
      const static std::string	interrupt_message ("User interruption");
      QProgressDialog&		dialog  = **d_;

      dialog.setValue(cur >> 16);
      qApp->processEvents();
      return dialog.wasCanceled() ? &interrupt_message : 0;
    }

    inline
    void
    MainWindow::addTrace(Trace* t)
    {
      assert(t);
      assert(not t->parent());
      assert(t->trace());

      const QString	traceName = (boost::lexical_cast<std::string>
				     (*t->trace()).c_str());

      connect(t, SIGNAL(positionChanged(int)), SLOT(updatePosition(int)));
      connect(t, SIGNAL(positionChanged(int)), t, SLOT(setFocus()));

      connect(t, SIGNAL(packetLeftClicked(int)), SLOT(updateHexDock(int)));
      connect(t, SIGNAL(packetDoubleLeftClicked(int)), SLOT(showHexDock(int)));

      tabs_.setCurrentIndex(tabs_.addTab(t, QFileInfo (traceName).fileName()));
      if (tabs_.count() == 1)
	updateTrace();
    }

    inline
    Trace*
    MainWindow::trace()
    {
      QWidget* const	w = tabs_.currentWidget();
      Trace* const	t = dynamic_cast<Trace*> (w);

      assert(not w or t);
      return t;
    }

    inline
    const Trace*
    MainWindow::trace() const
    {
      const QWidget* const	w = tabs_.currentWidget();
      const Trace* const	t = dynamic_cast<const Trace*> (w);

      assert(not w or t);
      return t;
    }

    inline
    QString
    MainWindow::openDirectoryHint() const
    {
      const Trace* const t = trace();

      return t ?
	QFileInfo (boost::lexical_cast<std::string>
		   (*t->trace()).c_str()).absolutePath():
	QDir::currentPath();
    }

    inline
    MainWindow*
    MainWindow::setupNewWindow(MainWindow* w, bool show)
    {
      w->setAttribute(Qt::WA_DeleteOnClose);
      if (show)
	w->show();
      return w;
    }

  } // End of namespace gui.

} // End of namespace wscout.

#endif // ! WSCOUT_GUI_MAIN_WINDOW_HXX_
