/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007, 2008, 2009  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#include <boost/date_time/posix_time/posix_time.hpp>

#include "wscout_gui_pcap_header.hh"

namespace wscout
{

  namespace gui
  {

    PcapHeader::next_header
    PcapHeader::setup(const void*, size_t,
		      const Trace&	trace,
		      const packet&	desc)
    {
      using namespace boost::posix_time;
      using namespace boost::gregorian;

      const wpl::pkt::metadata&	d = desc.meta();

      const ptime		toa (date(1970, Jan, 01),
				     seconds (d.ts.tv_sec) +
				     microseconds (d.ts.tv_usec));

      setUpdatesEnabled(false);
      id_.setText(tr("#%1").arg(desc.meta().id));
      date_.setText(tr("%1").arg(to_simple_string(toa).c_str()));
      len_.setText(tr("%1 / %2 byte(s)").arg(d.caplen).arg(d.len));
      setUpdatesEnabled(true);

      return nextHeader(trace, desc);
    }

  } // End of namespace gui.

} // End of namespace wscout.
