/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007, 2008, 2009  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_PCAP_HEADER_HH_
# define WSCOUT_GUI_PCAP_HEADER_HH_

# include <utility>

# include <QtGui/QLabel>

# include <wipal/pcap/stream.hh>

# include "wscout_gui_trace.hh"
# include "wscout_gui_header_base.hh"
# include "wscout_protocol_ids.hh"

namespace wscout
{

  namespace gui
  {

     /// PCAP header widget.
    struct PcapHeader: public HeaderBase<PcapHeader, protocol::PCAP>
    {
      /// Default constructor.
      PcapHeader(QWidget* parent = 0);

      /// Setup the widget for a given trace and packet.
      virtual next_header	setup(const void*	bytes,
				      size_t		caplen,
				      const Trace&	trace,
				      const packet&	desc);

      /// Retrieve the next header's description.
      static next_header	nextHeader(const Trace&		t,
					   const packet&	d);

    private:
      QLabel	id_;
      QLabel	date_;
      QLabel	len_;
    };

  } // End of namespace gui.

} // End of namespace wscout.

# include "wscout_gui_pcap_header.hxx"

#endif // ! WSCOUT_GUI_PCAP_HEADER_HH_
