/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007, 2008, 2009  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_PCAP_HEADER_HXX_
# define WSCOUT_GUI_PCAP_HEADER_HXX_

# include "wscout_gui_pcap_header.hh"

namespace wscout
{

  namespace gui
  {

    inline
    PcapHeader::PcapHeader(QWidget* parent):
      HeaderBase<PcapHeader, protocol::PCAP> (parent)
    {
      {
	QFont bold;

	bold.setBold(true);
	id_.setFont(bold);
      }
      {
	QBoxLayout* const l = layout();

	l->addWidget(&id_);
	l->addWidget(&date_);
	l->addStretch();
	l->addWidget(&len_);
      }
    }

    inline
    PcapHeader::next_header
    PcapHeader::nextHeader(const Trace&		trace,
			   const packet&	desc)
    {
      const wpl::pcap::indexed_file<>*	d = trace.trace();
      protocol::id			i;

      assert(d);

      switch (d->type())
	{
	case wpl::pkt::IEEE802_11:
	  i = protocol::IEEE802_11;
	  break;
	case wpl::pkt::IEEE802_11_RADIO_AVS:
	  i = protocol::AVS_HEADER;
	  break;
	case wpl::pkt::PRISM_HEADER:
	  i = protocol::PRISM_HEADER;
	  break;
	default:
	  i = protocol::UNKNOWN;
	  break;
	}
      return next_header (i, desc.bytes());
    }

  } // End of namespace gui.

} // End of namespace wscout.

#endif // ! WSCOUT_GUI_PCAP_HEADER_HXX_
