/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_PHY_HEADER_HH_
# define WSCOUT_GUI_PHY_HEADER_HH_

# include <QtGui/QLabel>
# include <QtGui/QLineEdit>

extern "C"
{
# include <stdint.h>
}

# include "wscout_gui_header_base.hh"

namespace wscout
{

  namespace gui
  {

    /**
     * Base clase for PHY header widgets (e.g. Prism/AVS).
     *
     * @see AbstractHeader, HeaderBase
     */
    template <class Exact, int Proto>
    struct PHYHeader: public HeaderBase<Exact, Proto>
    {
      enum
      {
	default_spacing	= 16 ///< Spacing between text labels.
      };

      /// Default constructor.
      PHYHeader(const QString& proto, QWidget* parent = 0);

    protected:
      void	setTruncated(bool trunc = true);
      void	setTime(uint64_t hosttime, uint64_t mactime);
      void	setRate(float rate);
      void	setChannel(unsigned channel);
      void	setSignal(int rssi, int signal, int noise);

    private:
      QString	proto_str_;
      QLabel	proto_;
      QLineEdit	time_;
      QLabel	rate_;
      QLabel	channel_;
      QLabel	signal_;
    };

  } // End of namespace gui.

} // End of namespace wscout.

# include "wscout_gui_phy_header.hxx"

#endif // ! WSCOUT_GUI_PHY_HEADER_HH_
